/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, ElementRef, NgZone, AfterViewInit } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { PreventableEvent } from '../common/preventable-event';
import { SVGIcon } from '@progress/kendo-svg-icons';
import * as i0 from "@angular/core";
/**
 * Represents the [Kendo UI DialogTitleBar component for Angular]({% slug api_dialog_dialogtitlebarcomponent %}).
 *
 * It is used as part of the Dialog content when the component is created dynamically by using an [Angular service]({% slug service_dialog %}).
 */
export declare class DialogTitleBarComponent implements AfterViewInit {
    private zone;
    private hostElement;
    private localizationService;
    /**
     * Fires when the close button of the title-bar is clicked.
     */
    close: EventEmitter<PreventableEvent>;
    /**
     * @hidden
     */
    id: string;
    /**
     * @hidden
     */
    closeTitle: string;
    get className(): true;
    /**
     * @hidden
     */
    xIcon: SVGIcon;
    constructor(zone: NgZone, hostElement: ElementRef, localizationService: LocalizationService);
    get closeButtonTitle(): string;
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    onCloseClick(e: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DialogTitleBarComponent, [null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DialogTitleBarComponent, "kendo-dialog-titlebar", never, { "id": "id"; "closeTitle": "closeTitle"; }, { "close": "close"; }, never, ["*"], true, never>;
}
